==> servicecatalog-model-6.9.0-sources.jar: io/fabric8/servicecatalog/api/model/ParametersFromSourceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParametersFromSourceFluent<A extends ParametersFromSourceFluent<A>> extends BaseFluent<A>{
  public ParametersFromSourceFluent() {
  }
  
  public ParametersFromSourceFluent(ParametersFromSource instance) {
    this.copyInstance(instance);
  }
  private SecretKeyReferenceBuilder secretKeyRef;
  
  protected void copyInstance(ParametersFromSource instance) {
    instance = (instance != null ? instance : new ParametersFromSource());
  
    if (instance != null) {
        this.withSecretKeyRef(instance.getSecretKeyRef());
        this.withSecretKeyRef(instance.getSecretKeyRef());
      }
  }
  
  public SecretKeyReference buildSecretKeyRef() {
    return this.secretKeyRef!=null ?this.secretKeyRef.build():null;
  }
  
  public A withSecretKeyRef(SecretKeyReference secretKeyRef) {
    _visitables.get("secretKeyRef").remove(this.secretKeyRef);
    if (secretKeyRef!=null){ this.secretKeyRef= new SecretKeyReferenceBuilder(secretKeyRef); _visitables.get("secretKeyRef").add(this.secretKeyRef);} else { this.secretKeyRef = null; _visitables.get("secretKeyRef").remove(this.secretKeyRef); } return (A) this;
  }
  
  public boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  
  public A withNewSecretKeyRef(String key,String name) {
    return (A)withSecretKeyRef(new SecretKeyReference(key, name));
  }
  
  public SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new SecretKeyRefNested(null);
  }
  
  public SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeyReference item) {
    return new SecretKeyRefNested(item);
  }
  
  public SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(null));
  }
  
  public SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(new SecretKeyReferenceBuilder().build()));
  }
  
  public SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeyReference item) {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParametersFromSourceFluent that = (ParametersFromSourceFluent) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  public class SecretKeyRefNested<N> extends SecretKeyReferenceFluent<SecretKeyRefNested<N>> implements Nested<N>{
    SecretKeyRefNested(SecretKeyReference item) {
      this.builder = new SecretKeyReferenceBuilder(this, item);
    }
    SecretKeyReferenceBuilder builder;
    
    public N and() {
      return (N) ParametersFromSourceFluent.this.withSecretKeyRef(builder.build());
    }
    
    public N endSecretKeyRef() {
      return and();
    }
    
  
  }

}

==> servicecatalog-model-6.9.1-sources.jar: io/fabric8/servicecatalog/api/model/ParametersFromSourceFluent.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ParametersFromSourceFluent<A extends ParametersFromSourceFluent<A>> extends BaseFluent<A>{
  public ParametersFromSourceFluent() {
  }
  
  public ParametersFromSourceFluent(ParametersFromSource instance) {
    this.copyInstance(instance);
  }
  private SecretKeyReferenceBuilder secretKeyRef;
  
  protected void copyInstance(ParametersFromSource instance) {
    instance = (instance != null ? instance : new ParametersFromSource());
    if (instance != null) {
          this.withSecretKeyRef(instance.getSecretKeyRef());
          this.withSecretKeyRef(instance.getSecretKeyRef());
        }
  }
  
  public SecretKeyReference buildSecretKeyRef() {
    return this.secretKeyRef != null ? this.secretKeyRef.build() : null;
  }
  
  public A withSecretKeyRef(SecretKeyReference secretKeyRef) {
    this._visitables.remove(this.secretKeyRef);
    if (secretKeyRef != null) {
        this.secretKeyRef = new SecretKeyReferenceBuilder(secretKeyRef);
        this._visitables.get("secretKeyRef").add(this.secretKeyRef);
    } else {
        this.secretKeyRef = null;
        this._visitables.get("secretKeyRef").remove(this.secretKeyRef);
    }
    return (A) this;
  }
  
  public boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  
  public A withNewSecretKeyRef(String key,String name) {
    return (A)withSecretKeyRef(new SecretKeyReference(key, name));
  }
  
  public SecretKeyRefNested<A> withNewSecretKeyRef() {
    return new SecretKeyRefNested(null);
  }
  
  public SecretKeyRefNested<A> withNewSecretKeyRefLike(SecretKeyReference item) {
    return new SecretKeyRefNested(item);
  }
  
  public SecretKeyRefNested<A> editSecretKeyRef() {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(null));
  }
  
  public SecretKeyRefNested<A> editOrNewSecretKeyRef() {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(new SecretKeyReferenceBuilder().build()));
  }
  
  public SecretKeyRefNested<A> editOrNewSecretKeyRefLike(SecretKeyReference item) {
    return withNewSecretKeyRefLike(java.util.Optional.ofNullable(buildSecretKeyRef()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ParametersFromSourceFluent that = (ParametersFromSourceFluent) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  public class SecretKeyRefNested<N> extends SecretKeyReferenceFluent<SecretKeyRefNested<N>> implements Nested<N>{
    SecretKeyRefNested(SecretKeyReference item) {
      this.builder = new SecretKeyReferenceBuilder(this, item);
    }
    SecretKeyReferenceBuilder builder;
    
    public N and() {
      return (N) ParametersFromSourceFluent.this.withSecretKeyRef(builder.build());
    }
    
    public N endSecretKeyRef() {
      return and();
    }
    
  
  }

}
